============================
``support.bitvector`` module
============================

.. automodule:: whoosh.idsets


Base classes
============

.. autoclass:: DocIdSet
    :members:

.. autoclass:: BaseBitSet


Implementation classes
======================

.. autoclass:: BitSet
.. autoclass:: OnDiskBitSet
.. autoclass:: SortedIntSet
.. autoclass:: MultiIdSet
